# -*- coding: utf-8 -*-

'''
@author: Gabriele Girelli
@contact: gigi.ga90@gmail.com
@description: methods for FASTA manipulation.
'''

# DEPENDENCIES =================================================================

from Bio.SeqIO.FastaIO import SimpleFastaParser
from tqdm import tqdm

# CONSTANTS ====================================================================

tqdm.monitor_interval = 0

# FUNCTIONS ====================================================================

def count_records(fpath):
    '''Quickly count headers in FASTA file.

    Args:
        fpath (str): path to input FASTA file.
    
    Returns:
        int: number of headers (lines starting with ">")
    '''
    rc = 0
    with open(fpath, "r") as IH:
        for line in IH:
            if ">" == line[0]:
                rc += 1
    return(rc)

def read_seq(ipath, opath = None, n = None):
    '''Converts a FASTA file into a header-less fasta file with one sequence
    per line.

    Args:
        ipath (str): path to input FASTA.
        opath (str): path to output header-less FASTA.
        n (int): number of sequences in input file for progress bar.
    
    Returns:
        list: sequences from the input FASTA.
        None: writes to disk.
    '''
    if type(None) == type(opath):
        l = []
        with open(ipath, 'r') as IH:
            seqgen = SimpleFastaParser(IH)
            if type(None) != type(n): seqgen = tqdm(seqgen, total = n)

            for record in seqgen: l.append(record[1])
        return(l)
    else:
        with open(opath, 'w+') as OH:
            with open(ipath, 'r') as IH:
                seqgen = SimpleFastaParser(IH)
                if type(None) != type(n): seqgen = tqdm(seqgen, total = n)

                for record in seqgen:
                    if 0 != len(record[1]):
                        OH.write("%s\n" % record[1])

# END ==========================================================================

################################################################################



"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
import os

here = os.path.abspath(os.path.dirname(__file__))
bindir = os.path.join(here, "bin/")

# Get the long description from the README file
with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
	long_description = f.read()

setup(name='ggc',
	version='0.0.1',
	description='''Basic methods, for common usage across packages''',
	long_description=long_description,
	url='https://github.com/ggirelli/ggc',
	long_description_content_type='text/markdown',
	author='Gabriele Girelli',
	author_email='gabriele.girelli@scilifelab.se',
	license='MIT',
	classifiers=[
		'Development Status :: 4 - Beta',
		'Intended Audience :: Science/Research',
		'Topic :: Scientific/Engineering :: Bio-Informatics',
		'License :: OSI Approved :: MIT License',
		'Programming Language :: Python :: 3 :: Only',
	],
	keywords='common',
	packages=find_packages(),
	install_requires=["biopython", "tqdm"],
	scripts=[],
	test_suite="nose.collector",
	tests_require=["nose"],
)
